@@ -56,7 +56,9 @@ import com.openexchange.capabilities.CapabilityService;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.config.Reloadable;
 import com.openexchange.config.cascade.ConfigViewFactory;
+import com.openexchange.dispatcher.DispatcherPrefixService;
 import com.openexchange.exception.OXException;
+import com.openexchange.http.deferrer.DeferringURLService;
 import com.openexchange.oauth.OAuthServiceMetaData;
 import com.openexchange.oauth.twitter.OAuthServiceMetaDataTwitterImpl;
 import com.openexchange.oauth.twitter.TwitterOAuthServiceRegistry;
@@ -82,7 +84,7 @@ public final class TwitterOAuthActivator extends HousekeepingActivator {
 
     @Override
     protected Class<?>[] getNeededServices() {
-        return new Class<?>[] { ConfigurationService.class, CapabilityService.class, ConfigViewFactory.class };
+        return new Class<?>[] { ConfigurationService.class, CapabilityService.class, ConfigViewFactory.class, DeferringURLService.class, DispatcherPrefixService.class };
     }
 
     @Override
@@ -95,7 +97,7 @@ public final class TwitterOAuthActivator extends HousekeepingActivator {
             /*
              * Register service
              */
-            final OAuthServiceMetaDataTwitterImpl service = new OAuthServiceMetaDataTwitterImpl();
+            final OAuthServiceMetaDataTwitterImpl service = new OAuthServiceMetaDataTwitterImpl(this);
             registerService(OAuthServiceMetaData.class, service);
             registerService(Reloadable.class, service);
 
